php

package
v0.0.0-...-0ac02d5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 14, 2018 License: BSD-3-Clause Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewHandler

func NewHandler(docroot, network, address string) http.Handler

NewHandler returns a fastcgi web server implementation as an http.Handler Please note that this handler doesn't handle the fastcgi application process. You'd need to start it with other means.

docroot: the document root of the PHP site. network: network protocol (tcp / tcp4 / tcp6)

or if it is a unix socket, "unix"

address: IP address and port, or the socket physical address of the fastcgi

application.

Types

This section is empty.

Jump to