Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewHandler ¶
NewHandler returns a fastcgi web server implementation as an http.Handler Please note that this handler doesn't handle the fastcgi application process. You'd need to start it with other means.
docroot: the document root of the PHP site. network: network protocol (tcp / tcp4 / tcp6)
or if it is a unix socket, "unix"
address: IP address and port, or the socket physical address of the fastcgi
application.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.